Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(662)

Unified Diff: net/proxy/proxy_server.cc

Issue 149191: Whenever proxy configurations contain socks and http/https/ftp proxies, socks... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/proxy/proxy_server.h ('k') | net/proxy/proxy_server_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_server.cc
===================================================================
--- net/proxy/proxy_server.cc (revision 20472)
+++ net/proxy/proxy_server.cc (working copy)
@@ -85,15 +85,17 @@
}
// static
-ProxyServer ProxyServer::FromURI(const std::string& uri) {
- return FromURI(uri.begin(), uri.end());
+ProxyServer ProxyServer::FromURI(const std::string& uri,
+ Scheme default_scheme) {
+ return FromURI(uri.begin(), uri.end(), default_scheme);
}
// static
ProxyServer ProxyServer::FromURI(std::string::const_iterator begin,
- std::string::const_iterator end) {
- // We will default to HTTP if no scheme specifier was given.
- Scheme scheme = SCHEME_HTTP;
+ std::string::const_iterator end,
+ Scheme default_scheme) {
+ // We will default to |default_scheme| if no scheme specifier was given.
+ Scheme scheme = default_scheme;
// Trim the leading/trailing whitespace.
HttpUtil::TrimLWS(&begin, &end);
« no previous file with comments | « net/proxy/proxy_server.h ('k') | net/proxy/proxy_server_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698